@@ -5,6 +5,7 @@ from nonebot.adapters.onebot.v11 import (
     MessageSegment,
     Message,
     GroupMessageEvent,
+    ActionFailed
 )
 from nonebot.params import Matcher, RegexGroup
 from nonebot.log import logger
@@ -104,7 +105,10 @@ async def _(
     if isinstance(event, GroupMessageEvent):
         group_id = args[1] if args[1] else str(event.group_id)
     else:
-        group_id = args[1]
+        if args[1]:
+            group_id = args[1]
+        else:
+            await matcher.finish("私聊开关需要输入指定群号")
     if mode == "开启":
         if group_id in CONFIG["opened_groups"]:
             await matcher.finish("该群已经开启，无需重复开启")
@@ -119,7 +123,7 @@ async def _(
         async with aiofiles.open(config_path, "w", encoding="utf8") as f:
             await f.write(json.dumps(CONFIG, ensure_ascii=False, indent=4))
     await matcher.finish(
-        f"已成功{mode}{(await bot.get_group_info(group_id=int(group_id)))['group_name']}({group_id})每日一句"
+        f"已成功{mode}{group_id}的每日一句"
     )
 
 
@@ -164,10 +168,13 @@ async def post_scheduler():
     bot: Bot = get_bot()
     delay = env_config.everyday_delay * 0.5
     for group_id in CONFIG["opened_groups"]:
-        await bot.send_group_msg(group_id=int(group_id), message=record)
-        await asyncio.sleep(delay)
-        await bot.send_group_msg(group_id=int(group_id), message=msg)
-        await asyncio.sleep(delay)
+        try:
+            await bot.send_group_msg(group_id=int(group_id), message=record)
+            await asyncio.sleep(delay)
+            await bot.send_group_msg(group_id=int(group_id), message=msg)
+            await asyncio.sleep(delay)
+        except ActionFailed:
+            logger.warning(f"定时发送每日一句到 {group_id} 失败，可能是风控或机器人不在该群聊")
 
 
 if scheduler:
